@@ -339,7 +339,7 @@ To insert a signature file automatically, call the function
 
     ;;  Pure binary
 
-    ("\\.jpg$"
+    ("\\.jpg$\\|\\.jpeg$"
      "image"	"jpeg"		nil
      "base64"
      "inline"		(("filename" . file))
@@ -669,7 +669,14 @@ If it is not specified for a major-mode,
 				  ;; XEmacs versions earlier than 21.1.1.
 				  (format " (patch %d)" emacs-patch-level))
 				 (t ""))
-			   " (" xemacs-codename ") ("
+			   " (" xemacs-codename ")"
+			   ;; `xemacs-extra-name' has appeared in the
+			   ;; development version of XEmacs 21.5-b8.
+			   (if (and (boundp 'xemacs-extra-name)
+				    (symbol-value 'xemacs-extra-name))
+			       (concat " " (symbol-value 'xemacs-extra-name))
+			     "")
+			   " ("
 			   system-configuration ")")
 			" (" emacs-version ")"))
 	    (let ((ver (if (string-match "\\.[0-9]+$" emacs-version)
@@ -797,9 +804,9 @@ Tspecials means any character that matches with it in header must be quoted.")
     (encrypted	"Enclose as encrypted"	mime-edit-enclose-pgp-encrypted-region)
     (quote	"Verbatim region"	mime-edit-enclose-quote-region)
     (key	"Insert Public Key"	mime-edit-insert-key)
-    (split	"About split"           mime-edit-set-split)
-    (sign	"About sign"		mime-edit-set-sign)
-    (encrypt	"About encryption"	mime-edit-set-encrypt)
+    (split	"Set splitting"		mime-edit-set-split)
+    (sign	"PGP sign"		mime-edit-set-sign)
+    (encrypt	"PGP encrypt"		mime-edit-set-encrypt)
     (preview	"Preview Message"	mime-edit-preview-message)
     (level	"Toggle transfer-level"	mime-edit-toggle-transfer-level)
     )
@@ -1495,7 +1502,7 @@ Nil if no such parameter."
 	;; Change value
 	(concat (substring ctype 0 (match-beginning 1))
 		parameter "=" value
-		(substring contype (match-end 1))
+		(substring ctype (match-end 1))
 		opt-fields)
       (concat ctype "; " parameter "=" value opt-fields)
       )))
@@ -1593,7 +1600,7 @@ Optional DELIMITER specifies parameter delimiter (';' by default)."
 
 (defun mime-prompt-for-parameter (parameter)
   "Ask for PARAMETER.
-Parameter must be '(PROMPT CHOICE1 (CHOISE2 ...))."
+Parameter must be '(PROMPT CHOICE1 (CHOICE2...))."
   (let* ((prompt (car parameter))
 	 (choices (mapcar (function
 			   (lambda (e)
@@ -2663,7 +2670,7 @@ Content-Type: message/partial; id=%s; number=%d; total=%d\n%s\n"
 	  (message (format "Sending %d/%d..."
 			   mime-edit-partial-number total))
 	  (call-interactively command)
-	  (message (format "Sending %d/%d... done"
+	  (message (format "Sending %d/%d...done"
 			   mime-edit-partial-number total))
 	  )
 	(setq mime-edit-partial-number
@@ -2681,7 +2688,7 @@ Content-Type: message/partial; id=%s; number=%d; total=%d\n%s\n"
       (save-excursion
 	(message (format "Sending %d/%d..."
 			 mime-edit-partial-number total))
-	(message (format "Sending %d/%d... done"
+	(message (format "Sending %d/%d...done"
 			 mime-edit-partial-number total))
 	)
       )))
@@ -2930,7 +2937,8 @@ Content-Type: message/partial; id=%s; number=%d; total=%d\n%s\n"
 			(setq encoded t
 			      encoding nil)
 			)))))))
-    (if (or encoded (not not-decode-text))
+    (if (and (eq type 'text)
+	     (or encoded (not not-decode-text)))
  	(progn
  	  (save-excursion
  	    (goto-char (point-min))
